@@ -73,10 +73,24 @@ def generate_training_data_for_cloudnet(
         {"site": site, "product": "classification"},
         timeout=60,
     ).json()
+    try:
+        classification_dates = [row["measurementDate"] for row in classification_metadata]
+    except TypeError:
+        logging.error(f"Invalid site '{site}'.")
+        return
+    if not classification_dates:
+        logging.error(f"No classification files found for site '{site}'.")
+        return
     rpg_metadata = requests.get(
-        f"{url}/raw-files", {"site": site, "instrument": "rpg-fmcw-94"}, timeout=60
+        f"{url}/raw-files",
+        {
+            "site": site,
+            "instrument": "rpg-fmcw-94",
+            "dateFrom": min(classification_dates),
+            "dateTo": max(classification_dates),
+        },
+        timeout=60,
     ).json()
-    classification_dates = [row["measurementDate"] for row in classification_metadata]
     rpg_metadata = [
         row
         for row in rpg_metadata
@@ -92,6 +106,9 @@ def generate_training_data_for_cloudnet(
         rpg_metadata = [
             row for row in rpg_metadata if row["measurementDate"] in classification_dates
         ]
+    if not classification_metadata:
+        logging.error(f"No matching classification / RPG Level 0 files found for site '{site}'.")
+        return
     voodoo_droplet = VoodooDroplet(None, options, training_options)
     features, labels = voodoo_droplet.compile_dataset_using_api(
         rpg_metadata, classification_metadata
@@ -171,7 +188,7 @@ class VoodooDroplet:
         self.target_time = target_time
         self.options = options
         self.training_options = training_options
-        self.prob_liquid = np.array([])
+        self.prob_liquid: np.ndarray = np.array([])
         self._feature_list: list = []
         self._label_list: list = []
 
@@ -224,7 +241,7 @@ class VoodooDroplet:
 
         for classification_meta in classification_metadata:
             logging.info(f"Categorize file: {classification_meta['filename']}")
-            res = session.get(classification_meta["downloadUrl"], timeout=20)
+            res = session.get(classification_meta["downloadUrl"])
             with NamedTemporaryFile() as temp_file:
                 with open(temp_file.name, "wb") as f:
                     f.write(res.content)
@@ -243,7 +260,7 @@ class VoodooDroplet:
                 logging.info(f"Processing {n_files} RPG files...")
 
             for rpg_meta in rpg_files_of_day:
-                res = session.get(rpg_meta["downloadUrl"], timeout=20)
+                res = session.get(rpg_meta["downloadUrl"])
                 with NamedTemporaryFile() as temp_file:
                     with open(temp_file.name, "wb") as f:
                         f.write(res.content)
@@ -289,11 +306,15 @@ class VoodooDroplet:
             features_tensor = utils.numpy_arrays2tensor(self._feature_list)
             label_tensor = utils.numpy_arrays2tensor(self._label_list)
             return features_tensor, label_tensor
-        logging.error("No valid categorize / RPG Level 0 files.")
+        logging.error("No valid classification / RPG Level 0 files.")
         return Tensor([]), Tensor([])
 
     def _extract_features(self, filename: str) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
-        header, data = read_rpg(filename)
+        try:
+            header, data = read_rpg(filename)
+        except IndexError:
+            logging.error(f"Error reading RPG file {filename}")
+            return np.array([]), np.array([]), np.array([])
         self._init_arrays(header, data)
         assert self.target_time is not None
         radar_time = utils.rpg_time2unix(data["Time"])
@@ -343,7 +364,7 @@ class VoodooDroplet:
         voodoo_net.load_state_dict(
             torch.load(self.options.trained_model, map_location=self.options.device)["state_dict"]
         )
-        prediction = voodoo_net.predict(tensor, batch_size=256).to(self.options.device)
+        prediction = voodoo_net.predict(tensor, batch_size=256).to("cpu")
         return prediction
 
     def _hyperspectral_image(
